config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

# Keep same perms on rc.udev.new:
if [ -e etc/rc.d/rc.udev ]; then
  cp -a etc/rc.d/rc.udev etc/rc.d/rc.udev.new.incoming
  cat etc/rc.d/rc.udev.new > etc/rc.d/rc.udev.new.incoming
  mv etc/rc.d/rc.udev.new.incoming etc/rc.d/rc.udev.new
fi

# There's no reason for a user to edit rc.udev, so overwrite it:
if [ -r etc/rc.d/rc.udev.new ]; then
  mv etc/rc.d/rc.udev.new etc/rc.d/rc.udev
fi

# This should catch *all* files in /etc/modprobe.d/ and move them over to
# have .conf extensions
for modfile in $(ls etc/modprobe.d/ | grep -v "\.\(conf\|bak\|orig\|new\)"); do
  if [ -e etc/modprobe.d/$modfile -a ! -e etc/modprobe.d/$modfile.conf ]; then
    mv etc/modprobe.d/$modfile etc/modprobe.d/$modfile.conf
  elif [ -e etc/modprobe.d/$modfile -a -e etc/modprobe.d/$modfile.conf ]; then
    mv etc/modprobe.d/$modfile etc/modprobe.d/$modfile.bak
  fi
done

config etc/modprobe.d/blacklist.conf.new
config etc/modprobe.d/isapnp.conf.new
config etc/modprobe.d/psmouse.conf.new
config etc/modprobe.d/usb-controller.conf.new

/sbin/udevadm info --convert-db 1>/dev/null 2>/dev/null

( cd sbin ; rm -rf scsi_id )
( cd sbin ; ln -sf ../lib/udev/scsi_id scsi_id )
( cd sbin ; rm -rf vol_id )
( cd sbin ; ln -sf ../lib/udev/vol_id vol_id )
( cd lib ; rm -rf libudev.so.0 )
( cd lib ; ln -sf libudev.so.0.10.0 libudev.so.0 )
( cd lib ; rm -rf libgudev-1.0.so.0 )
( cd lib ; ln -sf libgudev-1.0.so.0.1.0 libgudev-1.0.so.0 )
( cd lib/udev/devices ; rm -rf X0R )
( cd lib/udev/devices ; ln -sf null X0R )
( cd usr/lib ; rm -rf libgudev-1.0.so )
( cd usr/lib ; ln -sf ../../lib/libgudev-1.0.so.0.1.0 libgudev-1.0.so )
( cd usr/lib ; rm -rf libudev.so )
( cd usr/lib ; ln -sf ../../lib/libudev.so.0.10.0 libudev.so )
( cd usr/lib/ConsoleKit/run-seat.d ; rm -rf udev-acl.ck )
( cd usr/lib/ConsoleKit/run-seat.d ; ln -sf /lib/udev/udev-acl udev-acl.ck )
